presto-package: presto: Fast differential expression

presto-packageR Documentation

presto: Fast differential expression

Description

Scalable implementation of the Wilcoxon rank sum test and the area under the receiver operating characteristic curve (also known as auROC or AUC) statistic. Interfaces to dense and sparse matrices, as well as the genomics analysis frameworks 'Seurat' and 'SingleCellExperiment'.

Author(s)

Maintainer: Kamil Slowikowski kslowikowski@gmail.com (ORCID) [contributor]

Authors:

Other contributors:

  • Austin Hartman (ORCID) [contributor]


presto documentation built on Sept. 30, 2026, 5:13 p.m.