| top_markers_dds | R Documentation |
Filters and ranks the long-form output of pseudobulk_deseq2() to
give the most distinguishing features per group. The filtering
arguments combine multiplicatively, then the top n features per
group are kept by descending Wald statistic and pivoted into wide
form. Counterpart to top_markers() for Wilcoxon-based results.
top_markers_dds(res, n = 10, pval_max = 1, padj_max = 1, lfc_min = 1)
res |
Long-form DESeq2 results from |
n |
Number of top features to return per group. Default |
pval_max |
Filter features with raw |
padj_max |
Filter features with adjusted |
lfc_min |
Filter features with |
tibble in wide form: a rank column (1..n) and one
column per group containing the gene identifier of the top-ranked
feature at that rank. Cells are NA for groups that have fewer
than n features passing the filters.
pseudobulk_deseq2(), top_markers()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.